DEPOClient
==========

PHP client for [DEPO service](http://depo.sk), pertaining to
[api v1](http://admin.depo.sk/apigility/documentation/Api-v1).



Installation
------------

Download (clone, extract, whatever) the source codes.
Run `composer install` to install dependencies.
Tested on PHP 5.6, should work with PHP 7 as well.



Usage
-----

### Constructing a client

```
// path to depo client directory
require_once 'depo_client_dir/bootstrap.php';

// set up configuration
$config = [
    // those directories have to be writable
    // by default those are in depo client directory
	'temp_dir' => __DIR__.'/temp',
	'log_dir' => __DIR__.'/log',
	'pdf_dir' => __DIR__.'/pdf',
	// \Monolog\Logger costant
	// default value: Logger::ERROR
	'log_level' => Logger::ERROR,
	// credentials for DEPO admin
	'username' => 'test',
	'password' => 'test',
	// without trailing slash
	'base_url' => 'http://admin.depo.sk/v1/api'
];

try {
	$client = new \DEPOClient\Client($config);
} catch(\DEPOClient\Exceptions\DEPOException $e) {
	die('Missing configuration');
}
```

### Getting a list of available places

```
// places are cached on local disk
// to update the cache, use this
// (in cron, for example)
$client->updatePlacesCache();

// use this method to get all available places
// also available as json in depo_client_dir/temp/places.json
// if cache is empty, it is automatically updated
$places = $client->getPlaces();
```

### Managing a package

```
// 1 - SENDING
// how to send a package
$package = new \DEPOClient\Entities\Package();
// this example includes required fields only
// has to be an existing place id
$package->target = '31703542';
// price of the package
$package->insurance = 100;
$package->recipient_name = 'Josef Válek';
$package->recipient_phone = '00420774874302';
$package->recipient_email = 'valek@1webit.cz';

// exception is thrown when something fails
try {
	$client->sendPackage($package);

	// store this number to database or do whatever you want with it
	$number = $package->getNumber();
} catch(\DEPOClient\Exceptions\DEPOException) {
	// exceptions are logged to log directory
}


// 2 - GETTING INFO
try {
	$package = $client->getPackage('123123123');
} catch (\DEPOClient\Exceptions\DEPOException) {
	// an exception is thrown if the package
	// does not exist
}

// 3 - GENERATING LABEL
$label = new \DEPOClient\Entities\Label();
$label->number = '123123123';
$label->size = '2x2';
try {
	$client->generateLabel($label);
	// output pdf ...
	header("Content-type:application/pdf");
	echo(file_get_contents($label->pdf_filename));
} catch (\DEPOClient\Exceptions\DEPOException) {
}


// 4 - CANCELING
try {
	$package = $client->cancelPackage('123123123');
} catch (\DEPOClient\Exceptions\DEPOException) {
	// an exception is thrown if something goes wrong
}
```


Develompment notes
------------------

Client is defined by \DEPOClient\ClientInterface. All methods should throw
an exception on (logical) failure, instead of returning `FALSE` or `NULL` values.

TODO
----

 - [ ] Describe how entities work.
 - [ ] Add getPlace($id) method
 - [ ] Add getPackages() example
